@@ -11,13 +11,16 @@ class POSTagger(stanford.POSTagger):
 			kwargs['path_to_model'] = 'resources/persian.tagger'
 		if 'path_to_jar' not in kwargs:
 			kwargs['path_to_jar'] = 'resources/stanford-postagger.jar'
+
+		self._SEPARATOR = '/'
 		super(stanford.POSTagger, self).__init__(*args, **kwargs)
 
 	def tag_sents(self, sentences):
 		"""
 		>>> tagger.tag(['من', 'به', 'مدرسه', 'رفته بودم', '.'])
-		[('من', 'PR'), ('به', 'PREP'), ('مدرسه', 'N'), ('رفته بودم', 'V'), ('.', 'PUNC')]
+		[('من', 'PRO'), ('به', 'P'), ('مدرسه', 'N'), ('رفته بودم', 'V'), ('.', 'PUNC')]
 		"""
-		_sentences = [[item.replace(' ', '_') for item in sentence] for sentence in sentences]
-		results = super(stanford.POSTagger, self).tag_sents(_sentences)
-		return [[(word, tag[1].split('/')[-1]) for word, tag in zip(sentence, result)] for sentence, result in zip(sentences, results)]
+
+		refined = map(lambda s: [w.replace(' ', '_') for w in s], sentences)
+		tagged = super(stanford.POSTagger, self).tag_sents(refined)
+		return list(map(lambda s: [(w.replace('_', ' '), t) for w, t in s], tagged))
